/**************************** CPP SOURCE FILE ********************************
**
**  Project:    RTCU Communication Hub, Heartbeat plug-in
**  Filename:   HEARTBEAT.CPP 
**  Version:    1.00
**  Date:       June 23, 2020
**  
******************************************************************************
**
**  VERSION HISTORY:
**  ----------------
**  1.00 - June 23, 2020 - Michael Olsen
**  - The function for handling heartbeat events are implemented.
**
*****************************************************************************/


/*****************************************************************************
**
** MODULES USED 
**
*****************************************************************************/
#include <Windows.h>
#include <string>
#include "local.h"


/*****************************************************************************
**
**    DEFINITIONS AND MACROS
**
*****************************************************************************/


/****************************************************************************
**
**    TYPEDEFS AND STRUCTURES
**
****************************************************************************/


/*****************************************************************************
**
** EXPORTED VARIABLES 
**
*****************************************************************************/


/*****************************************************************************
**
** GLOBAL VARIABLES 
**
*****************************************************************************/


/*****************************************************************************
**
** LOCAL FUNCTIONS 
**
*****************************************************************************/


/*****************************************************************************
**
** EXPORTED FUNCTIONS 
**
*****************************************************************************/

/////////////////////////////////////////////////////////////////////////////
// This function is called from the RCH when a Heartbeat event happens.
//
// Input:
//    NodeID        - The Node ID of the client.
//    Event         - The heartbeat event.
//                    1 = The client is online. (first heartbeat received)
//                    2 = The client is offline. (Timeout waiting for heartbeat)
//
// Output:
//    None.
//
// Returns:
//    None.
//
/////////////////////////////////////////////////////////////////////////////
void OnHeartbeat(const long NodeID, const int Event)
{
    // Var
    char text[200];

    // Build text
    if (Event == 1)
        sprintf_s(text, sizeof(text), "%ld::Heartbeat online", NodeID);
    else
        sprintf_s(text, sizeof(text), "%ld::Heartbeat offline", NodeID);

    // Show
    write_log(2, text);
}

/****************************************************************************
**
**    EOF 
**
****************************************************************************/
