/***************************** C HEADER FILE *********************************
**
**  Project:    RTCU Communication Hub, Namelist plug-in
**  Filename:   LOCAL.H 
**  Version:    1.00
**  Date:       January 30, 2019
**  
******************************************************************************
**
**  VERSION HISTORY:
**  ----------------
**  1.00 - January 30, 2019 - Michael Olsen
**  - Ported to RCH.
**
*****************************************************************************/
#if !defined(_LOCAL_H_)
#define _LOCAL_H_


/*****************************************************************************
**
**    MODULES USED 
**
*****************************************************************************/


/*****************************************************************************
**
**    DEFINITIONS AND MACROS
**
*****************************************************************************/


/****************************************************************************
**
**    TYPEDEFS AND STRUCTURES
**
****************************************************************************/


/****************************************************************************
** 
**    EXPORTED VARIABLES
**
****************************************************************************/


/****************************************************************************
**
**    EXPORTED FUNCTIONS
**
****************************************************************************/

/////////////////////////////////////////////////////////////////////////////
// This function will write an entry into the Gateway log.
//
// Input:
//    type          - The type of log entry.
//                    1 = Error, 2 = Event, 3 = detailed event
//    text          - Pointer to the zero terminated UTF-8 string to enter.
//
// Output:
//    None.
//
// Returns:
//    None.
//
/////////////////////////////////////////////////////////////////////////////
void write_log(const int type, const char *text);

/////////////////////////////////////////////////////////////////////////////
// This function will initialize the name list functionality.
//
// Input:
//    config        - Pointer to the configuration string from the Gateway.
//
// Output:
//    None.
//
// Returns:
//    0             - Plug-in is initialized.
//    1             - Illegal configuration string.
//    2             - No file specified in configuration.
//    3             - XML file with namelist is not found.
//
/////////////////////////////////////////////////////////////////////////////
int  InitNamelist(const char *config);

/////////////////////////////////////////////////////////////////////////////
// This function will stop the namelist and cleanup resources.
//
// Input:
//    None.
//
// Output:
//    None.
//
// Returns:
//    None.
//
/////////////////////////////////////////////////////////////////////////////
void StopNamelist(void);

/////////////////////////////////////////////////////////////////////////////
// This function is called from the Gateway when starting to iterate the
// names in the list. The list will be locked until iteration is completed.
//
// Input:
//    name_len      - Pointer to a variable that holds the length of the
//                    name buffer in Bytes. If the buffer is to small it
//                    will hold the size required.
//
// Output:
//    name          - Pointer to the buffer where the name is stored.
//                    The name is a zero terminated UTF-8 string.
//    node          - Pointer to the buffer where the Node ID is stored.
//
// Returns:
//    0             - The name and node id is returned.
//    1             - One or more of the parameters are missing.
//    2             - The name buffer is not large enough.
//    3             - No more names in list.
//
/////////////////////////////////////////////////////////////////////////////
int  GetFirstName(char *name, int *name_len, long *node);

/////////////////////////////////////////////////////////////////////////////
// This function is called from the Gateway when iterate the names in the
// list, after the iteration is started.
// The list will be locked until iteration is completed.
//
// Input:
//    name_len      - Pointer to a variable that holds the length of the
//                    name buffer in Bytes. If the buffer is to small it
//                    will hold the size required.
//
// Output:
//    name          - Pointer to the buffer where the name is stored.
//                    The name is a zero terminated UTF-8 string.
//    node          - Pointer to the buffer where the Node ID is stored.
//
// Returns:
//    0             - The name and node id is returned.
//    1             - One or more of the parameters are missing.
//    2             - The name buffer is not large enough.
//    3             - No more names in list.
//
/////////////////////////////////////////////////////////////////////////////
int  GetNextName(char *name, int *name_len, long *node);


#endif   /* _LOCAL_H_ */
/****************************************************************************
**
**    EOF 
**
****************************************************************************/
